#!/usr/bin/env python
#
#	Copyright 2013-2014, Marten de Vries
#
#	Licensed under the Apache License, Version 2.0 (the "License");
#	you may not use this file except in compliance with the License.
#	You may obtain a copy of the License at
#
#	http://www.apache.org/licenses/LICENSE-2.0
#
#	Unless required by applicable law or agreed to in writing, software
#	distributed under the License is distributed on an "AS IS" BASIS,
#	WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#	See the License for the specific language governing permissions and
#	limitations under the License.

import subprocess
import shutil
import os
import pouchdb.utils

def disableMod(mod):
	with open(mod + ".py", "w") as f:
		f.write("raise ImportError()")

with pouchdb.utils.suppress(OSError):
	shutil.rmtree("build")
with pouchdb.utils.suppress(OSError):
	shutil.rmtree("htmlcov")
with pouchdb.utils.suppress(OSError):
	os.remove(".coverage")

subprocess.call(["python-coverage", "run", "-m", "unittest", "-fc", "pouchdb.tests"])
subprocess.call(["python-coverage", "html"])

with open(os.devnull, "w") as f:
	subprocess.call(["python3", "setup.py", "build"], stdout=f)

with pouchdb.utils.suppress(OSError):
	shutil.copy(
		os.path.join("pouchdb", "tests", "testconfig.json"),
		os.path.join("build", "lib", "pouchdb", "tests", "testconfig.json")
	)
os.chdir(os.path.join("build", "lib"))

unittest = ["-c", "import logging; logging.getLogger('urllib3').setLevel('ERROR'); logging.basicConfig(level='INFO'); import runpy; runpy.run_module('unittest')"]
for mod in ["non-existing-mod", "PySide", "PyQt5"]:
	disableMod(mod)
	subprocess.call(["python3", "-Wd"] + unittest + ["-fc", "pouchdb.tests"])
